@@ -1,6 +1,6 @@
 /*  cdrdao - write audio CD-Rs in disc-at-once mode
  *
- *  Copyright (C) 1998, 1999  Andreas Mueller <mueller@daneb.ping.de>
+ *  Copyright (C) 1998-2001  Andreas Mueller <andreas@daneb.de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,12 +16,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-/*
- * $Log: port.h,v $
- * Revision 1.1  1999/05/11 20:03:29  mueller
- * Initial revision
- *
- */
 
 #ifndef __PORT_H__
 #define __PORT_H__
@@ -34,5 +28,6 @@ void mSleep(long milliSeconds);
 void installSignalHandler(int sig, SignalHandler);
 void blockSignal(int sig);
 void unblockSignal(int sig);
+int setRealTimeScheduling(int priority);
 
 #endif
