@@ -1,4 +1,4 @@
-/* @(#)getargs.h	1.5 96/05/09 Copyright 1985 J. Schilling */
+/* @(#)getargs.h	1.9 03/06/15 Copyright 1985 J. Schilling */
 /*
  *	Definitions for getargs()/getallargs()/getfiles()
  *
@@ -15,20 +15,35 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License along with
+ * this program; see the file COPYING.  If not, write to the Free Software
+ * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 #ifndef	_GETARGS_H
 #define	_GETARGS_H
 
+#ifndef _MCONFIG_H
+#include <mconfig.h>
+#endif
+#ifndef _PROTOTYP_H
+#include <prototyp.h>
+#endif
+
+#ifdef	__cplusplus
+extern "C" {
+#endif
+
 #define	NOARGS		  0	/* No more args			*/
 #define	NOTAFLAG	  1	/* Not a flag type argument	*/
-#define BADFLAG		(-1)	/* Not a valid flag argument	*/
-#define BADFMT		(-2)	/* Error in format string	*/
+#define	BADFLAG		(-1)	/* Not a valid flag argument	*/
+#define	BADFMT		(-2)	/* Error in format string	*/
 #define	NOTAFILE	(-3)	/* Seems to be a flag type	*/
 
 typedef	int	(*getargfun)	__PR((const void *, void *));
 
+#ifdef	__cplusplus
+}
+#endif
+
 #endif	/* _GETARGS_H */
